@@ -1,7 +1,7 @@
 import os
 import sys
 from pythonbrew.basecommand import Command
-from pythonbrew.define import PATH_PYTHONS, PATH_BIN, PATH_ETC_TEMP
+from pythonbrew.define import PATH_PYTHONS, PATH_HOME_ETC_TEMP
 from pythonbrew.util import Package
 from pythonbrew.log import logger
 
@@ -12,24 +12,23 @@ class UseCommand(Command):
     
     def run_command(self, options, args):
         if not args:
-            logger.info("Unrecognized command line argument: argument not found.")
+            self.parser.print_help()
             sys.exit(1)
         pkg = Package(args[0])
         pkgname = pkg.name
         pkgdir = os.path.join(PATH_PYTHONS, pkgname)
         if not os.path.isdir(pkgdir):
-            logger.info("`%s` is not installed." % pkgname)
+            logger.error("`%s` is not installed." % pkgname)
             sys.exit(1)
         pkgbin = os.path.join(pkgdir,'bin')
         
-        self._set_temp('%s:%s' % (PATH_BIN, pkgbin))
+        self._set_temp(pkgbin)
         
         logger.info("Using `%s`" % pkgname)
 
     def _set_temp(self, path):
-        fp = open(PATH_ETC_TEMP, 'w')
-        fp.write('PATH_PYTHONBREW="%s"\n' % (path))
+        fp = open(PATH_HOME_ETC_TEMP, 'w')
+        fp.write('PATH_PYTHONBREW_TEMP="%s"\n' % (path))
         fp.close()
 
-
 UseCommand()
