@@ -3,10 +3,10 @@ from pythonbrew.log import logger
 from pythonbrew.define import INSTALLER_ROOT, ROOT, PATH_ETC
 
 def install_pythonbrew():
-    PythonbrewInstaller().install(INSTALLER_ROOT)
-    # pythonbrew is only for bash
+    PythonbrewInstaller.install(INSTALLER_ROOT)
+    # for bash
     shrc = yourshrc = "bashrc"
-    logger.info("""
+    logger.log("""
 Well-done! Congratulations!
 
 The pythonbrew is installed as:
@@ -33,4 +33,30 @@ Enjoy pythonbrew at %(ROOT)s!!
 """ % {'ROOT':ROOT, 'yourshrc':yourshrc, 'shrc':shrc, 'PATH_ETC':PATH_ETC})
 
 def upgrade_pythonbrew():
-    PythonbrewInstaller().install(INSTALLER_ROOT)
+    PythonbrewInstaller.install(INSTALLER_ROOT)
+
+def systemwide_pythonbrew():
+    PythonbrewInstaller.install(INSTALLER_ROOT)
+    PythonbrewInstaller.systemwide_install()
+    logger.log("""
+Well-done! Congratulations!
+
+The pythonbrew is installed as:
+    
+  %(ROOT)s
+
+After that, exit this shell, start a new one, and install some fresh
+pythons:
+
+  pythonbrew install 2.7.2
+  pythonbrew install 3.2
+
+For further instructions, run:
+
+  pythonbrew help
+
+The default help messages will popup and tell you what to do!
+
+Enjoy pythonbrew at %(ROOT)s!!
+""" % {'ROOT':ROOT})
+        
\ No newline at end of file
