@@ -1,4 +1,4 @@
-from pythonbrew.installer import install_pythonbrew, upgrade_pythonbrew
+from pythonbrew.installer import install_pythonbrew, upgrade_pythonbrew, systemwide_pythonbrew
 from optparse import OptionParser
 if __name__ == "__main__":
     parser = OptionParser()
@@ -9,8 +9,17 @@ if __name__ == "__main__":
         default=False,
         help="Upgrade."
     )
+    parser.add_option(
+        '--systemwide',
+        dest="systemwide",
+        action="store_true",
+        default=False,
+        help="systemwide install."
+    )
     (opt, arg) = parser.parse_args()
-    if opt.upgrade:
+    if opt.systemwide:
+        systemwide_pythonbrew()
+    elif opt.upgrade:
         upgrade_pythonbrew()
     else:
         install_pythonbrew()
